@@ -9,9 +9,21 @@ __END__
 
 =head1 NAME
 
+CSS::Croco::Term - value of CSS property
+
 =head1 DESCRIPTION
 
+Abstract class, do not used directly
 
+=head1 METHODS
+
+=head2 get
+
+Returns value
+
+=head2 to_string
+
+Returns string representation of value
 
 =head1 BUGS
 
